(function(o){typeof define=="function"&&define.amd?define(o):o()})(function(){"use strict";function o(i,e,a,u){if(!(i instanceof Error))throw i;if(!(typeof window>"u"&&e||u))throw i.message+=" on line "+a,i;var t,r,l,c;try{u=u||require("fs").readFileSync(e,{encoding:"utf8"}),t=3,r=u.split(`
`),l=Math.max(a-t,0),c=Math.min(r.length,a+t)}catch(n){return i.message+=" - could not read from "+e+" ("+n.message+")",void o(i,null,a)}t=r.slice(l,c).map(function(n,F){var s=F+l+1;return(s==a?"  > ":"    ")+s+"| "+n}).join(`
`),i.path=e;try{i.message=(e||"Pug")+":"+a+`
`+t+`

`+i.message}catch{}throw i}function E(i){var e="",a,u;try{u=1,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/fileListWidgetCreateButton.pug",e=e+'<a class="g-create-thumbnail" title="Create thumbnail of this file">',u=2,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/fileListWidgetCreateButton.pug",e=e+'<i class="icon-picture"></i></a>'}catch(t){o(t,a,u)}return e}var T=girder.models.Model.extend({resourceName:"thumbnail"});function y(i){var e=""+i,a=j.exec(e);if(!a)return i;var u,t,r,l="";for(u=a.index,t=0;u<e.length;u++){switch(e.charCodeAt(u)){case 34:r="&quot;";break;case 38:r="&amp;";break;case 60:r="&lt;";break;case 62:r="&gt;";break;default:continue}t!==u&&(l+=e.substring(t,u)),t=u+1,l+=r}return t!==u?l+e.substring(t,u):l}var j=/["&<>]/;function d(i,e,a,u){if(!(i instanceof Error))throw i;if(!(typeof window>"u"&&e||u))throw i.message+=" on line "+a,i;var t,r,l,c;try{u=u||require("fs").readFileSync(e,{encoding:"utf8"}),t=3,r=u.split(`
`),l=Math.max(a-t,0),c=Math.min(r.length,a+t)}catch(n){return i.message+=" - could not read from "+e+" ("+n.message+")",void d(i,null,a)}t=r.slice(l,c).map(function(n,F){var s=F+l+1;return(s==a?"  > ":"    ")+s+"| "+n}).join(`
`),i.path=e;try{i.message=(e||"Pug")+":"+a+`
`+t+`

`+i.message}catch{}throw i}function V(i){var e="",a,u,t;try{var r=i||{};(function(l){t=1,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<div class="modal-dialog">',t=2,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<div class="modal-content">',t=3,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<form class="modal-form" id="g-create-thumbnail-form" role="form">',t=4,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<div class="modal-header">',t=5,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<button class="close" data-dismiss="modal" aria-hidden="true" type="button">',t=5,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+"&times;</button>",t=6,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<h4 class="modal-title">',t=6,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+"Create thumbnail</h4>",t=7,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<div class="g-dialog-subtitle">',t=8,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<i class="icon-doc-inv"></i>',t=9,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+" ",t=9,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+y((a=l.get("name"))==null?"":a)+"</div></div>",t=10,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<div class="modal-body">',t=11,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+"<label>",t=11,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+"Thumbnail size (px)</label>",t=12,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<div class="g-thumbnail-size-form-container">',t=13,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<input class="g-thumbnail-size-input" id="g-thumbnail-width" placeholder="width"/>',t=14,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<span class="g-thumbnail-size-between">',t=14,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+"&times;</span>",t=15,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<input class="g-thumbnail-size-input" id="g-thumbnail-height" placeholder="height"/>',t=16,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<label class="g-thumbnail-crop-container checkbox-inline">',t=17,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<input id="g-thumbnail-crop" type="checkbox"/>',t=18,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+"Crop</label></div>",t=19,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+"<label>",t=19,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+"Attach to",t=20,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<div class="g-thumbnail-attach-container">',t=21,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<label class="radio-inline">',t=22,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<input class="g-thumbnail-attach-this-item" type="radio" name="g-thumbnail-attach-to" checked="on"/>',t=23,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+"This item</label>",t=24,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<label class="radio-inline">',t=25,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<input class="g-thumbnail-attach-something-else" type="radio" name="g-thumbnail-attach-to"/>',t=26,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+"Something else...</label></div></label>",t=27,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<div class="g-thumbnail-custom-target-container hide">',t=28,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<div class="g-target-result-container"></div>',t=29,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<div class="g-search-field-container"></div></div>',t=30,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<div class="g-validation-failed-message"></div></div>',t=31,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<div class="modal-footer">',t=32,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<a class="btn btn-small btn-default" data-dismiss="modal">',t=32,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+"Close</a>",t=33,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<button class="g-submit-create-thumbnail btn btn-small btn-primary" type="submit">',t=34,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+'<i class="icon-picture"></i>',t=35,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewDialog.pug",e=e+" Create</button></div></form></div></div>"}).call(this,"file"in r?r.file:typeof file<"u"?file:void 0)}catch(l){d(l,u,t)}return e}function $(i,e,a,u){if(e===!1||e==null||!e&&(i==="class"||i==="style"))return"";if(e===!0)return" "+(u?i:i+'="'+i+'"');var t=typeof e;return t!=="object"&&t!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),a||e.indexOf('"')===-1)?(a&&(e=h(e))," "+i+'="'+e+'"'):" "+i+"='"+e.replace(/'/g,"&#39;")+"'"}function p(i,e){return Array.isArray(i)?D(i,e):i&&typeof i=="object"?x(i):i||""}function D(i,e){for(var a,u="",t="",r=Array.isArray(e),l=0;l<i.length;l++)(a=p(i[l]))&&(r&&e[l]&&(a=h(a)),u=u+t+a,t=" ");return u}function x(i){var e="",a="";for(var u in i)u&&i[u]&&k.call(i,u)&&(e=e+a+u,a=" ");return e}function h(i){var e=""+i,a=A.exec(e);if(!a)return i;var u,t,r,l="";for(u=a.index,t=0;u<e.length;u++){switch(e.charCodeAt(u)){case 34:r="&quot;";break;case 38:r="&amp;";break;case 60:r="&lt;";break;case 62:r="&gt;";break;default:continue}t!==u&&(l+=e.substring(t,u)),t=u+1,l+=r}return t!==u?l+e.substring(t,u):l}var k=Object.prototype.hasOwnProperty,A=/["&<>]/;function b(i,e,a,u){if(!(i instanceof Error))throw i;if(!(typeof window>"u"&&e||u))throw i.message+=" on line "+a,i;var t,r,l,c;try{u=u||require("fs").readFileSync(e,{encoding:"utf8"}),t=3,r=u.split(`
`),l=Math.max(a-t,0),c=Math.min(r.length,a+t)}catch(n){return i.message+=" - could not read from "+e+" ("+n.message+")",void b(i,null,a)}t=r.slice(l,c).map(function(n,F){var s=F+l+1;return(s==a?"  > ":"    ")+s+"| "+n}).join(`
`),i.path=e;try{i.message=(e||"Pug")+":"+a+`
`+t+`

`+i.message}catch{}throw i}function I(i){var e="",a,u,t;try{var r=i||{};(function(l,c){t=1,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewTargetDescription.pug",e=e+'<div class="g-target-result">',t=2,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewTargetDescription.pug",e=e+"<i"+$("class",p([`icon-${l}`],[!0]),!1,!1)+"></i>",t=3,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewTargetDescription.pug",e=e+" ",t=3,u="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/createThumbnailViewTargetDescription.pug",e=e+h((a=c)==null?"":a)+"</div>"}).call(this,"icon"in r?r.icon:typeof icon<"u"?icon:void 0,"text"in r?r.text:typeof text<"u"?text:void 0)}catch(l){b(l,u,t)}return e}const i0="",M=girder.views.View,S=girder.views.widgets.SearchFieldWidget;var L=M.extend({events:{'change .g-thumbnail-attach-container input[type="radio"]':function(){this.$(".g-target-result-container").empty(),this.$(".g-thumbnail-attach-this-item").is(":checked")?(this.attachToType="item",this.attachToId=this.item.id,this.$(".g-thumbnail-custom-target-container").addClass("hide"),this.$(".g-submit-create-thumbnail").girderEnable(!0)):(this.attachToType=null,this.attachToId=null,this.$(".g-thumbnail-custom-target-container").removeClass("hide"),this.$(".g-submit-create-thumbnail").girderEnable(!1))},"submit #g-create-thumbnail-form":function(i){i.preventDefault(),this.$(".g-validation-failed-message").empty(),this.$(".g-submit-create-thumbnail").girderEnable(!1),new T({width:Number(this.$("#g-thumbnail-width").val())||0,height:Number(this.$("#g-thumbnail-height").val())||0,crop:this.$("#g-thumbnail-crop").is(":checked"),fileId:this.file.id,attachToId:this.attachToId,attachToType:this.attachToType}).on("g:saved",function(){this.$el.on("hidden.bs.modal",()=>{this.trigger("g:created",{attachedToType:this.attachToType,attachedToId:this.attachToId})}).modal("hide")},this).on("g:error",function(e){this.$(".g-submit-create-thumbnail").girderEnable(!0),this.$(".g-validation-failed-message").text(e.responseJSON.message)},this).save()}},initialize:function(i){this.item=i.item,this.file=i.file,this.attachToType="item",this.attachToId=this.item.id,this.searchWidget=new S({placeholder:"Start typing a name...",types:["collection","folder","item","user"],parentView:this}).on("g:resultClicked",this.pickTarget,this)},render:function(){return this.$el.html(V({file:this.file,item:this.item})).girderModal(this).on("shown.bs.modal",()=>{this.$("#g-thumbnail-width").trigger("focus")}),this.$("#g-thumbnail-width").trigger("focus"),this.searchWidget.setElement(this.$(".g-search-field-container")).render(),this},pickTarget:function(i){this.searchWidget.resetState(),this.attachToType=i.type,this.attachToId=i.id,this.$(".g-submit-create-thumbnail").girderEnable(!0),this.$(".g-target-result-container").html(I({text:i.text,icon:i.icon}))}});const f=girder.$,W=girder.Backbone,w=girder.views.widgets.FileListWidget,{wrap:N}=girder.utilities.PluginUtils,{AccessType:O}=girder.constants,q=girder.router;N(w,"render",function(i){return i.call(this),this.parentItem.getAccessLevel()>=O.WRITE&&this.$(".g-file-actions-container").prepend(E()),this}),w.prototype.events["click a.g-create-thumbnail"]=function(i){var e=f(i.currentTarget).parent().attr("file-cid");new L({el:f("#g-dialog-container"),parentView:this,item:this.parentItem,file:this.collection.get(e)}).once("g:created",function(a){W.history.fragment=null,q.navigate(a.attachedToType+"/"+a.attachedToId,{trigger:!0})},this).render()};function _(i,e,a,u){if(!(i instanceof Error))throw i;if(!(typeof window>"u"&&e||u))throw i.message+=" on line "+a,i;var t,r,l,c;try{u=u||require("fs").readFileSync(e,{encoding:"utf8"}),t=3,r=u.split(`
`),l=Math.max(a-t,0),c=Math.min(r.length,a+t)}catch(n){return i.message+=" - could not read from "+e+" ("+n.message+")",void _(i,null,a)}t=r.slice(l,c).map(function(n,F){var s=F+l+1;return(s==a?"  > ":"    ")+s+"| "+n}).join(`
`),i.path=e;try{i.message=(e||"Pug")+":"+a+`
`+t+`

`+i.message}catch{}throw i}function P(i){var e="",a,u;try{u=1,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/itemView.pug",e=e+'<div class="g-thumbnails-header-container">',u=2,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/itemView.pug",e=e+'<div class="g-item-info-header">',u=3,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/itemView.pug",e=e+'<i class="icon-picture"></i>',u=4,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/itemView.pug",e=e+"Thumbnails</div></div>"}catch(t){_(t,a,u)}return e}function m(i,e,a,u){if(e===!1||e==null||!e&&(i==="class"||i==="style"))return"";if(e===!0)return" "+(u?i:i+'="'+i+'"');var t=typeof e;return t!=="object"&&t!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),a||e.indexOf('"')===-1)?(a&&(e=z(e))," "+i+'="'+e+'"'):" "+i+"='"+e.replace(/'/g,"&#39;")+"'"}function z(i){var e=""+i,a=J.exec(e);if(!a)return i;var u,t,r,l="";for(u=a.index,t=0;u<e.length;u++){switch(e.charCodeAt(u)){case 34:r="&quot;";break;case 38:r="&amp;";break;case 60:r="&lt;";break;case 62:r="&gt;";break;default:continue}t!==u&&(l+=e.substring(t,u)),t=u+1,l+=r}return t!==u?l+e.substring(t,u):l}var J=/["&<>]/;function v(i,e,a,u){if(!(i instanceof Error))throw i;if(!(typeof window>"u"&&e||u))throw i.message+=" on line "+a,i;var t,r,l,c;try{u=u||require("fs").readFileSync(e,{encoding:"utf8"}),t=3,r=u.split(`
`),l=Math.max(a-t,0),c=Math.min(r.length,a+t)}catch(n){return i.message+=" - could not read from "+e+" ("+n.message+")",void v(i,null,a)}t=r.slice(l,c).map(function(n,F){var s=F+l+1;return(s==a?"  > ":"    ")+s+"| "+n}).join(`
`),i.path=e;try{i.message=(e||"Pug")+":"+a+`
`+t+`

`+i.message}catch{}throw i}function B(i){var e="",a,u;try{var t=i||{};(function(r,l,c){u=1,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/flowView.pug",e=e+'<div class="g-thumbnail-flow-container">',u=2,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/flowView.pug",(function(){var n=c;if(typeof n.length=="number")for(var F=0,s=n.length;F<s;F++){var g=n[F];u=3,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/flowView.pug",e=e+"<div"+(' class="g-thumbnail-container"'+m("g-file-id",g.id,!0,!1))+">",u=4,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/flowView.pug",l>=r.WRITE&&(u=5,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/flowView.pug",e=e+'<div class="g-thumbnail-actions-container">',u=6,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/flowView.pug",e=e+'<a class="g-thumbnail-delete" title="Delete">',u=7,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/flowView.pug",e=e+'<i class="icon-cancel"></i></a></div>'),u=8,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/flowView.pug",e=e+"<img"+(' class="g-thumbnail"'+m("src",g.downloadUrl(),!0,!1))+"/></div>"}else{var s=0;for(var F in n){s++;var g=n[F];u=3,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/flowView.pug",e=e+"<div"+(' class="g-thumbnail-container"'+m("g-file-id",g.id,!0,!1))+">",u=4,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/flowView.pug",l>=r.WRITE&&(u=5,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/flowView.pug",e=e+'<div class="g-thumbnail-actions-container">',u=6,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/flowView.pug",e=e+'<a class="g-thumbnail-delete" title="Delete">',u=7,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/flowView.pug",e=e+'<i class="icon-cancel"></i></a></div>'),u=8,a="/home/circleci/project/girder/plugins/thumbnails/girder_thumbnails/web_client/templates/flowView.pug",e=e+"<img"+(' class="g-thumbnail"'+m("src",g.downloadUrl(),!0,!1))+"/></div>"}}}).call(this),e=e+"</div>"}).call(this,"AccessType"in t?t.AccessType:typeof AccessType<"u"?AccessType:void 0,"accessLevel"in t?t.accessLevel:typeof accessLevel<"u"?accessLevel:void 0,"thumbnails"in t?t.thumbnails:typeof thumbnails<"u"?thumbnails:void 0)}catch(r){v(r,a,u)}return e}const t0="",R=girder.$,U=girder.views.View,{confirm:G}=girder.dialog,H=girder.events,K=girder.models.FileModel,{AccessType:C}=girder.constants;var Q=U.extend({events:{"click .g-thumbnail-delete":function(i){var e=R(i.currentTarget).parents(".g-thumbnail-container"),a=new K({_id:e.attr("g-file-id")});G({text:"Are you sure you want to delete this thumbnail?",yesText:"Delete",confirmCallback:()=>{a.on("g:deleted",function(){e.remove()}).on("g:error",function(){H.trigger("g:alert",{icon:"cancel",text:"Failed to delete thumbnail.",type:"danger",timeout:4e3})}).destroy()}})},"mouseenter .g-thumbnail-container":function(){this.$(".g-thumbnail-actions-container").addClass("g-show")},"mouseleave .g-thumbnail-container":function(){this.$(".g-thumbnail-actions-container").removeClass("g-show")}},initialize:function(i){this.thumbnails=i.thumbnails,this.accessLevel=i.accessLevel||C.READ},render:function(){return this.$el.html(B({thumbnails:this.thumbnails.toArray(),accessLevel:this.accessLevel,AccessType:C})),this}});const X=girder._,Y=girder.views.body.ItemView,{wrap:Z}=girder.utilities.PluginUtils,e0=girder.collections.FileCollection;Z(Y,"render",function(i){this.once("g:rendered",function(){const e=new e0(X.map(this.model.get("_thumbnails"),a=>({_id:a})));e&&e.length&&(this.$(".g-item-info").before(P()),new Q({className:"g-thumbnails-flow-view-container",parentView:this,thumbnails:e,accessLevel:this.model.getAccessLevel()}).render().$el.insertBefore(this.$(".g-item-info")))},this),i.call(this)})});
//# sourceMappingURL=girder-plugin-thumbnails.umd.cjs.map
